Running simulations
===================

.. automodule:: buildingspy.simulate

Dymola
------

.. automodule:: buildingspy.simulate.Dymola
   :members:
   :show-inheritance:

OpenModelica
------------

.. automodule:: buildingspy.simulate.OpenModelica
   :members:
   :show-inheritance:

Optimica
--------

.. automodule:: buildingspy.simulate.Optimica
   :members:
   :show-inheritance:

